@@ -8,6 +8,10 @@
 #endif
 
 
+#ifdef _WIN32
+#	pragma warning( disable : 4996 )		// crt secure warning
+#endif
+
 // utime Լ ó
 #if defined(_WIN32) || defined(__CYGWIN__)
 #	include <time.h>
@@ -29,7 +33,7 @@
 #	include <iconv.h>
 #endif
 
-#if defined(__linux__) || defined(__GLIBC__) || defined(__GNU__)
+#if defined(__linux__) || defined(__GLIBC__) || defined(__GNU__) || defined(__APPLE__)
 #	include <errno.h>
 #endif
 
@@ -38,11 +42,6 @@
 #	include <errno.h>		// iconv.h  ʿ 
 #endif
 
-#ifdef _WIN32				// string conversion
-#	include <atlbase.h>
-#	include <atlconv.h>
-#endif
-
 #ifdef _WIN32				// safe string ó
 #	include <strsafe.h>
 #endif
@@ -118,6 +117,16 @@ static BOOL IsBigEndian(void)
 #endif
 
 
+// 64bit file handling support
+#if (_FILE_OFFSET_BITS==64)
+#	define unalz_fseek	fseeko
+#	define unalz_ftell	ftello
+#else
+#	define unalz_fseek	fseek
+#	define unalz_ftell	ftell
+#endif
+
+
 // error string table <- CUnAlz::ERR  
 static const char* errorstrtable[]=
 {
@@ -236,8 +245,9 @@ void CUnAlz::SetCallback(_UnAlzCallback* pFunc, void* param)
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 BOOL CUnAlz::Open(LPCWSTR szPathName)
 {
-	USES_CONVERSION;
-	return Open(W2A(szPathName));
+	char szPathNameA[MAX_PATH];
+	::WideCharToMultiByte(CP_ACP, 0, szPathName, -1, szPathNameA, MAX_PATH, NULL, NULL);
+	return Open(szPathNameA);
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 ///            ϱ.
@@ -247,8 +257,9 @@ BOOL CUnAlz::Open(LPCWSTR szPathName)
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 BOOL CUnAlz::SetCurrentFile(LPCWSTR szFileName)
 {
-	USES_CONVERSION;
-	return SetCurrentFile(W2A(szFileName));
+	char szFileNameA[MAX_PATH];
+	::WideCharToMultiByte(CP_ACP, 0, szFileName, -1, szFileNameA, MAX_PATH, NULL, NULL);
+	return SetCurrentFile(szFileNameA);
 }
 BOOL CUnAlz::IsFolder(LPCWSTR szPathName)
 {
@@ -278,7 +289,7 @@ BOOL CUnAlz::Open(const char* szPathName)
 		BOOL		ret;
 
 		if(FEof()) break;
-		//int pos = ftell(m_fp);
+		//int pos = unalz_ftell(m_fp);
 		sig = ReadSignature();
 		if(sig==SIG_EOF)
 		{
@@ -444,7 +455,7 @@ BOOL CUnAlz::ReadLocalFileheader()
 	size_t size;
 	char inbuf[ICONV_BUF_SIZE];
 	char outbuf[ICONV_BUF_SIZE];
-#if defined(__FreeBSD__) || defined(__CYGWIN__) || defined(__APPLE__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__CYGWIN__) ||  defined(__NetBSD__)
 	const char *inptr = inbuf;
 #else
 	char *inptr = inbuf;
@@ -1494,9 +1505,9 @@ BOOL CUnAlz::FOpen(const char* szPathName)
 		m_files[i].fp = fopen(temp, "rb");
 		if(m_files[i].fp==NULL) break;
 		dwFileSizeHigh=0;
-		fseek(m_files[i].fp,0,SEEK_END);		
-		nFileSizeLow=ftell(m_files[i].fp);
-		fseek(m_files[i].fp,0,SEEK_SET);
+		unalz_fseek(m_files[i].fp,0,SEEK_END);		
+		nFileSizeLow=unalz_ftell(m_files[i].fp);
+		unalz_fseek(m_files[i].fp,0,SEEK_SET);
 #endif
 		m_nFileCount++;
 		m_files[i].nFileSize = ((INT64)nFileSizeLow) + (((INT64)dwFileSizeHigh)<<32);
@@ -1584,7 +1595,7 @@ BOOL CUnAlz::FSeek(INT64 offset)
 #ifdef _WIN32
 			SetFilePointer(m_files[i].fp, LONG(m_nCurFilePos), &remainHigh, FILE_BEGIN);
 #else
-			fseek(m_files[i].fp, m_nCurFilePos, SEEK_SET);
+			unalz_fseek(m_files[i].fp, m_nCurFilePos, SEEK_SET);
 #endif
 			return TRUE;
 		}
@@ -1668,7 +1679,7 @@ BOOL CUnAlz::FRead(void* buffer, UINT32 nBytesToRead, int* pTotRead )
 #ifdef _WIN32
 			SetFilePointer(m_files[m_nCurFile].fp, (int)m_nCurFilePos, NULL, FILE_BEGIN);
 #else
-			fseek(m_files[m_nCurFile].fp, m_nCurFilePos, SEEK_SET);
+			unalz_fseek(m_files[m_nCurFile].fp, m_nCurFilePos, SEEK_SET);
 #endif
 		}
 		else
