@@ -2,7 +2,7 @@
   UNALZ : read and extract module for ALZ format.
 
   LICENSE (zlib License)
-  Copyright (C) 2004-2007 kippler@gmail.com , http://www.kipple.pe.kr
+  Copyright (C) 2004-2009 kippler@gmail.com , http://www.kipple.pe.kr
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -41,7 +41,7 @@
 	- .ALZ   ϱ  . 
 	- ALZ BZIP2(̶  Ѱ ƴϰ,  CRC   ũ⸦  ), 
 	  DEFLATE  ˰ ZIP     .
-	  (bzip2  4.9x  Ͽ, deflate  5.x  Ͽ. 5.x ʹ bzip2 ʹ   )
+	  (bzip2   4.9x  Ͽ, deflate  5.x  Ͽ. 5.x ʹ bzip2 ʹ   )
 	- UnAlzBz2decompress.c  UnAlzbzlib.c   bzip2 ҽ alz   
 	  (deflate   ȵǾ  ׳ zlib  ᵵ .. bzip2   Ǿ 
 	   bzip2 ҽ ״  ȵȴ.)
@@ -113,6 +113,16 @@
 	2008/04/04	- debian    (by cwryu@debian )
 				- ҽ , NULL iterator  
 				- unalz 0.62
+	2009/01/09  - apple gcc   (by lacovnk)
+				- unalz 0.63
+	2009/01/20  - 2GB Ѵ  ó  (by bsjeon@hanmail)
+				-   κ 
+				- ҽ 
+				- unalz 0.64
+	2009/04/01  - bzip2 1.0.5 update
+				- vs2008   ̽ (atlconv Ⱦ, crt secure warning disable) (by kaisyu@gmail)
+				- unalz 0.65
+
   
    :
 	- alz    (deflate/ bzip2/raw)
@@ -218,8 +228,8 @@ namespace UNALZ
 #	pragma pack(1)
 #endif
 
-static const char UNALZ_VERSION[]   = "CUnAlz0.62";
-static const char UNALZ_COPYRIGHT[] = "Copyright(C) 2004-2008 by kippler@gmail.com ( http://www.kipple.pe.kr ) ";
+static const char UNALZ_VERSION[]   = "CUnAlz0.65";
+static const char UNALZ_COPYRIGHT[] = "Copyright(C) 2004-2009 by kippler@gmail.com ( http://www.kipple.pe.kr ) ";
 
 enum		{ALZ_ENCR_HEADER_LEN=12}; // xf86
 //   ..
@@ -562,7 +572,7 @@ private :		//    ó  (lapper^^?) Ŭ
 	INT64		m_nCurFilePos;						///<    ġ.
 	BOOL		m_bIsEOF;							///<   (  ؼ) Գ?
 
-	BOOL		m_bIsEncrypted;		// xf86
+	BOOL		m_bIsEncrypted;						///< by xf86
 	BOOL		m_bIsDataDescr;
 #define UNALZ_LEN_PASSWORD	512
 	char		m_szPasswd[UNALZ_LEN_PASSWORD];
