@@ -1,5 +1,43 @@
+/*
+  UNALZ : read and extract module for ALZ format.
+
+  LICENSE (zlib License)
+  Copyright (C) 2004-2009 kippler@gmail.com , http://www.kipple.pe.kr
+
+  This software is provided 'as-is', without any express or implied
+  warranty.  In no event will the authors be held liable for any damages
+  arising from the use of this software.
+
+  Permission is granted to anyone to use this software for any purpose,
+  including commercial applications, and to alter it and redistribute it
+  freely, subject to the following restrictions:
+
+  1. The origin of this software must not be misrepresented; you must not
+     claim that you wrote the original software. If you use this software
+     in a product, an acknowledgment in the product documentation would be
+     appreciated but is not required.
+  2. Altered source versions must be plainly marked as such, and must not be
+     misrepresented as being the original software.
+  3. This notice may not be removed or altered from any source distribution.
+
+   Ʈ   Ǵ    "ִ ״" ˴ϴ.  
+   쿡 ۼڴ  Ʈ   ؿ  å  ʽϴ.
+
+     ؼϴ 쿡 Ͽ   α׷ ϴ  뵵  Ʈ 
+  ϰ Ӱ     ִ  Գ ο˴ϴ.
+
+  1.  Ʈ ó ߸ ǥϰų  Ʈ ڽ ۼߴٰ ؼ  ˴ϴ. ǰ 
+      Ʈ ϴ  䱸  ƴ ǰ    ־ ֽø ϰڽϴ.
+  2.  ҽ  ݵ Ȯϰ ǥõǾ ϸ  Ʈ εǵ ߸ ǥؼ  ˴ϴ.
+  3.  ҽ     ϰų   ϴ.
+
+  =============================================================================================================
+*/
+
+
 #ifdef _WIN32
 #	pragma warning( disable : 4786 )		// stl warning ֱ
+#	pragma warning( disable : 4996 )		// crt secure warning
 #endif
 
 #include <stdio.h>
@@ -31,8 +69,11 @@ void Copyright()
 //	printf("unalz v0.55 (2006/03/10) \n");
 //	printf("unalz v0.60 (2006/12/31) \n");
 //	printf("unalz v0.61 (2007/02/10) \n");
-	printf("unalz v0.62 (2008/04/04) \n");
-	printf("Copyright(C) 2004-2008 by kippler@gmail.com (http://www.kipple.pe.kr) \n");
+//	printf("unalz v0.62 (2008/04/04) \n");
+//	printf("unalz v0.63 (2009/01/09) \n");
+//	printf("unalz v0.64 (2009/01/20) \n");
+	printf("unalz v0.65 (2009/04/01) \n");
+	printf("Copyright(C) 2004-2009 by kippler@gmail.com (http://www.kipple.pe.kr) \n");
 }
 
 
@@ -103,7 +144,7 @@ void UnAlzCallback(const char* szFileName, INT64 nCurrent, INT64 nRange, void* p
 #else
 		snprintf(szMessage, MSG_BUF_LEN, "unalziiiing : %s (%lldbytes) ", szFileName, nRange);
 #endif
-		printf("%s", szMessage);
+		printf("%s.", szMessage);
 		fflush(stdout);
 		nPrevPercent = -1;
 		return;
@@ -132,8 +173,8 @@ int main(int argc, char* argv[])
 
 	CUnAlz	unalz;
 	char* source=NULL;
-	char* destpath=".";
-	char* destcodepage=NULL;
+	const char* destpath=".";
+	const char* destcodepage=NULL;
 	char* password=NULL;
 	int   count;
 	BOOL  listMode = FALSE;
@@ -317,7 +358,7 @@ int main(int argc, char* argv[])
 			}
 		}
 		if(g_bPipeMode==FALSE)
-			printf("\ndone..\n");
+			printf("\ndone.\n");
 	}
 
 	return 0;
